@@ -8,17 +8,23 @@
 # @Description : 包含基本的文件读写，指定扩展名文件查找等基本工具
 
 
-__version__ = "0.10.6"
+__version__ = "0.11.6"
 
 
 import json
 import math
 import random
+import string
 from typing import List, Union
 
 from gitopenlib.utils import basics as gb
 
 
+def generate_random_strs(length: int):
+    """生成随机字符串"""
+    return "".join(random.sample(string.digits * 5 + string.ascii_letters * 4, length))
+
+
 def list_intersection(listA: list, listB: list):
     """
     求两个list的交集，listA中的哪些元素，在listB中出现了。
